@@ -1,6 +1,7 @@
 from small_text.integrations.pytorch.exceptions import PytorchNotFoundError
 
 try:
+    from small_text.integrations.transformers.classifiers.base import ModelLoadingStrategy
     from small_text.integrations.transformers.classifiers.classification import (
         transformers_collate_fn,
         FineTuningArguments,
@@ -8,7 +9,13 @@ try:
         TransformerBasedClassification,
         TransformerBasedEmbeddingMixin
     )
+    from small_text.integrations.transformers.classifiers.setfit import (
+        SetFitClassification,
+        SetFitModelArguments,
+        SetFitClassificationEmbeddingMixin
+    )
     from small_text.integrations.transformers.classifiers.factories import (
+        SetFitClassificationFactory,
         TransformerBasedClassificationFactory
     )
     from small_text.integrations.transformers.datasets import (
@@ -16,12 +23,17 @@ try:
         TransformersDatasetView
     )
     __all__ = [
+        'ModelLoadingStrategy',
         'transformers_collate_fn',
         'FineTuningArguments',
         'TransformerModelArguments',
-        'TransformerBasedEmbeddingMixin',
-        'TransformerBasedClassificationFactory',
         'TransformerBasedClassification',
+        'TransformerBasedEmbeddingMixin',
+        'SetFitClassification',
+        'SetFitModelArguments',
+        'SetFitClassificationEmbeddingMixin',
+        'TransformerBasedClassificationFactory',
+        'SetFitClassificationFactory',
         'TransformersDataset',
         'TransformersDatasetView'
     ]
