@@ -118,7 +118,7 @@ class EmbeddingTest(unittest.TestCase):
         self.assertEqual(clf.model.config.hidden_size, embedding_one.shape[1])
         self.assertEqual(clf.model.config.hidden_size, embedding_two.shape[1])
 
-    def test_embed_with_predictions(self):
+    def test_embed_with_proba(self):
         classifier_kwargs = {
             'fine_tuning_arguments': FineTuningArguments(0.2, 0.95),
             'num_epochs': 1
@@ -133,11 +133,13 @@ class EmbeddingTest(unittest.TestCase):
         clf = clf_factory.new()
         clf.fit(train_set)
 
-        embeddings, predictions = clf.embed(train_set, return_proba=True, embedding_method=self.embedding_method)
+        embeddings, proba = clf.embed(train_set,
+                                      return_proba=True,
+                                      embedding_method=self.embedding_method)
         self.assertEqual(2, len(embeddings.shape))
         self.assertEqual(len(train_set), embeddings.shape[0])
         self.assertEqual(clf.model.config.hidden_size, embeddings.shape[1])
-        self.assertEqual(len(train_set), predictions.shape[0])
+        self.assertEqual(len(train_set), proba.shape[0])
 
 
 class _TransformerBasedClassificationTest(object):
@@ -252,6 +254,30 @@ class _TransformerBasedClassificationTest(object):
             self.assertTrue(np.all([isinstance(y, np.int64) for y in y_pred]))
             self.assertTrue(np.logical_or(y_pred.all() >= 0, y_pred.all() <= 3))
 
+    def test_fit_and_predict_proba_dropout_sampling(self, num_classes=4, dropout_sampling=3):
+        model_args = TransformerModelArguments('sshleifer/tiny-distilroberta-base')
+        clf = TransformerBasedClassification(model_args,
+                                             num_classes,
+                                             multi_label=self.multi_label,
+                                             class_weight='balanced',
+                                             num_epochs=1)
+
+        train_set = self._get_dataset(num_samples=20)
+        test_set = self._get_dataset(num_samples=10)
+
+        clf.fit(train_set)
+
+        y_pred_proba = clf.predict_proba(test_set)
+        self.assertSequenceEqual((len(test_set), num_classes), y_pred_proba.shape)
+        self.assertTrue(isinstance(y_pred_proba, np.ndarray))
+        self.assertTrue(np.all([isinstance(p, np.float64) for pred in y_pred_proba for p in pred]))
+
+        y_pred_proba = clf.predict_proba(test_set, dropout_sampling=dropout_sampling)
+        self.assertSequenceEqual((len(test_set), dropout_sampling, num_classes), y_pred_proba.shape)
+        self.assertTrue(isinstance(y_pred_proba, np.ndarray))
+        self.assertTrue(np.all([isinstance(p, np.float64) for pred in y_pred_proba
+                                for sample in pred for p in sample]))
+
     def test_fit_validate(self):
 
         model_args = TransformerModelArguments('sshleifer/tiny-distilroberta-base')
